@@ -1,12 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <R_ext/PrtUtil.h> /* Rprintf */
 
-/*
-#include <assert.h>
-*/
-
 
 #define FALSE 0
 #define TRUE 1
@@ -15,17 +10,9 @@
 #define _MCGA_H_ 1
 #endif
 
-/*
-Cross over types for mcga.
-TWO_POINT_CROSS_OVER is not implemented yet.
-UNIFORM_CROSS_OVER is the best over all.
-*/
-enum ChromosomeType
-{
-    ONE_POINT_CROSS_OVER,
-    TWO_POINT_CROSS_OVER,
-    UNIFORM_CROSS_OVER
-};
+#ifndef _TYPES_H_
+#include "types.h"
+#endif
 
 /*
 Holds information for a Chromosome.
